@@ -8,6 +8,6 @@ from .db.models import (  # noqa
 from .demo import download_demo_data, prepare_demo_data  # noqa
 from .es.client import ElasticKNNClient  # noqa
 from .es.utils import load_csv_with_headers, load_embeddings_from_numpy  # noqa
-from .experiments import Experiment
+from .experiments import Experiment  # noqa
 from .indices import delete_index, list_indices, load_index, match_query  # noqa
 from .spaces import EmbeddingSpace, compare_embedding_spaces  # noqa
